#
# spec file for package phun
#
# This file and all modifications and additions to the pristine
# package are under the same license as the package itself.
#

# norootforbuild

Name:           phun
Summary:        2D physics sandbox
Version:        5.28
Release:        lp150.8.1
License:        Free for non-commercial use
Url:            http://www.algodoo.com/
Group:          Productivity/Other
Vendor:         openSUSE-Education
Requires:       glew
Requires:       libpng16-compat-devel
BuildRequires:  libpng16-compat-devel
BuildRequires:  ImageMagick
BuildRequires:  boost-devel
BuildRequires:  sed
%define boost_license_pkg %(rpmqpack | grep boost-license | head -n 1)
%define boost_lib_version %( echo "%boost_license_pkg" | sed -e "s|boost-license||g" )
# normally, boost_filesystem should be enough
Requires:       libboost_filesystem%{boost_lib_version} 
# but to be shure...
Requires:       libboost_iostreams%{boost_lib_version} 
Requires:       libboost_math%{boost_lib_version} 
Requires:       libboost_program_options%{boost_lib_version} 
Requires:       libboost_signals%{boost_lib_version} 
Requires:       libboost_system%{boost_lib_version} 
Requires:       libboost_thread%{boost_lib_version} 
Requires:       libboost_wave%{boost_lib_version} 
Requires:       libboost_regex%{boost_lib_version}
AutoReqProv:    off
Requires:       SDL_image
Requires:       SDL
%if 0%{?suse_version}
BuildRequires:  update-desktop-files 
%endif
BuildRequires:  chrpath 
%ifarch         %ix86 ppc
Source0:        Phun_beta_5_28_linux32.tar.bz2
%else
Source0:        Phun_beta_5_28_linux64.tar.bz2
BuildRequires:  glew-devel
BuildRequires:  boost-devel
%endif
Source1:        phun.png
Source2:        phun.desktop
%define         transdate 20090922
Source3:        phun-translations-%{transdate}.tar.bz2
Source4:        phun-rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%define         phundir %_libdir/phun

%description
Phun is a Master of Science Thesis by Computing Science student Emil Ernerfeldt
for supervisor Kenneth Bodin at VRLab, Umeå University. The solver is based on
work by Claude Lacoursière

Phun is meant to be a playground where people can be creative. It can also be
used as an educational tool to learn about physics concepts such as restitution
and friction.


Author:
-------
    Emil Ernerfeldt


%prep
%setup -q -n Phun -b3
%ifarch         %ix86 ppc
chrpath -r %{phundir} %name.bin
%endif
pushd %{_builddir}/phun-translations-%{transdate}
for file in $(find . -type f); do
	test -f %{_builddir}/Phun/$file || cp -v $file %{_builddir}/Phun/$(dirname $file)/
done
popd
rm data/language/Espa*
#
# fix wrong file encodings
#
sed -i "s|
||" *.txt

%build

%install
install -D -m644 %SOURCE1 %buildroot/%_datadir/pixmaps/%{name}.png
install -D -m644 %SOURCE2 %buildroot/%_datadir/applications/%{name}.desktop
mkdir -p %buildroot/%{phundir}
mkdir -p %buildroot/%{_bindir}
cp -a * %buildroot/%{phundir}/
rm %buildroot/%{phundir}/*.txt
#
# create wrapper start script
#
cat > %buildroot/%{_bindir}/%name << EOF
#!/bin/sh
cd %{phundir} || exit 1
export LD_LIBRARY_PATH=".:%{phundir}/lib:${LD_LIBRARY_PATH}" 
./phun.bin $@
EOF
chmod +x %buildroot/%_bindir/%name
rm %buildroot/%{phundir}/phun
#
# fix language files
#
pushd %buildroot/%{phundir}/data/language
for lang in $(ls *.txt *.cfg | sed "s/ /_/g" | sed "s/\(//g" | sed "s/\)//g" ); do
	echo "$lang"
	dos2unix -qo "$lang"
	if [ "$lang" != "$(echo $lang|iconv -f 8859_1 -t utf8 -)" ]; then	
		mv -v "$lang" "$(echo $lang|iconv -f 8859_1 -t utf8 -)"
	fi
done
popd
#
# desktop files and cleanup
#
%if 0%{?suse_version}
%suse_update_desktop_file -n %name Education X-KDE-Edu-Teaching
%endif
#
# fix libpng warning: iCCP known incorrect sRGB profile
#
for i in $(find "%buildroot/%{phundir}" type -f -name "*.png" ); do 
	mogrify "$i";
done
#
# 64 bit packaging failure
#
%ifarch         x86_64
GLEWLIB=$(ls %{_libdir}/libGLEW.so.* | head -n 1)
GLEWLIBVERSION=$(echo ${GLEWLIB#*.*.*})
ln -s $GLEWLIB %buildroot/%{phundir}/libGLEW.so.${GLEWLIBVERSION}
# hardcoded pathname in the binary, but works also with other GLEW library versions
ln -s $GLEWLIB %buildroot/%{phundir}/libGLEW.so.1.5
BOOSTLIB=$(ls %{_libdir}/libboost_filesystem.so.* | head -n 1)
BOOSTLIBVERSION=$(echo ${BOOSTLIB#*.*.*})
ln -s $BOOSTLIB %buildroot/%{phundir}/libboost_filesystem-gcc41-%{boost_lib_version}.so.$BOOSTLIBVERSION
ln -s %{_libdir}/libpng.so %buildroot/%{phundir}/libpng.so.3
%endif

%if ! 0%{?suse_version}
%post
%update_menus
/sbin/ldconfig

%postun
%clean_menus
/sbin/ldconfig
%else
%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig
%endif

%clean
rm -rf %buildroot

%files
%defattr(-,root,root)
%doc *.txt 
%_datadir/applications/%{name}.desktop
%_datadir/pixmaps/%{name}.png
%_bindir/phun
%{phundir}

%changelog
* Sun Jun 25 2017 lars@linux-schulserver.de
- use a more generic approach to identify the boost version
- export the LD_LIBRARY_PATH in the wrapper
- run mogrify on png files to avoid libpng warning output
- fix desktop file to call phun with full path (and no extension)
- link libpng.so into the working directory
* Tue Oct 25 2011 lars@linux-schulserver.de
- fix boost library dependency for 11.3
- require boost-devel on 11.3 and beyond to really fix bnc#600379
* Wed Sep 22 2010 lars@linux-schulserver.de
- fix file encodings for all txt files using sed instead of
  dos2unix
* Wed Apr 28 2010 lars@linux-schulserver.de
- fix boost library dependency for 11.2 and beyond (bnc#600379)
* Wed Dec 24 2008 lars@linux-schulserver.de
- require boost only on < 11.1 (and single libs on >11.1)
* Thu Nov 27 2008 lars@linux-schulserver.de
- update to 4.22 beta
  + Fixed a bug where Phun would crash when cloning after first
    deleting items (thanks for helping me replicate, tatt61880)
  + Added the console command App.GUI.dragUndo.
    If set to false, drags can't be undone.
  + Changed so that the clone tool only selects both the original
    and the clone iff ctrl is pressed upon release (good idea, tatt61880)
  + Fixed a bug where the clone tool would sometimes leave one
    object out of the clone preview
  + Fixed a bug where the scaletool would try to scale an empty
    group and crash (pointed out by tatt61880)
  + Fixed a bug where "toggle" in the hinge controls would be reset
    on undo (pointed out by vovams).
  + Fixed it so that a hinge toggle button that was on gets restored
    to being on when undoing or loading a scene.
  + Added improved logic for determening the mirror axis when
    binding a key to the mirror command.
  + Fixed a bug where the polygon positions after scale/mirror would
    be very inaccurate for objects far from origo (bug noticed by lucidliquid)
  + Added the command "Scene.MoveToOrigo" which moves the entire scene
    to the center of the world coordinate system. Improves floating point precision.
  + Fixed a problem with panning and zooming while using the
    clone tool (problem pointed out by guyboy)
- updated some translations
* Thu Sep 25 2008 lars@linux-schulserver.de
- moved to Education base repository
* Mon Aug 11 2008 lars@linux-schulserver.de
- update to 4.20 beta:
  + Added the ability to assign a key to destroy entities
  + Added the ability to assign a key to mirror a group of entities
  + Changed scale tool behavior to scale single circles towards
    their center
  + Reduced cpu usage on large scenes
  + You can now clone with CTRL when using the drag-tool
  + Added undo/redo for common scene settings
  + Added a auto-brake option to the hinge controller
  + Added a menu option to change the target length of a spring
  + Optimized input handling, especially on Linux
  + Fixed some bugs around water "visibility"
  + Added unit to the density slider (kg/m²)
  + Added the ability to double-click to open context menus,
    and to select all the text in a textbox
  ...see http://www.phunland.com/wiki/Phun_changelog for more
- create the wrapper script in the specfile
- added additional translations (manual collection from wiki)
* Fri Jul  4 2008 lars@linux-schulserver.de
- update to 4.11 beta:
  + Fixed a bug where undo:ing would reset the sky color, gravity etc
  + Fixed a bug where scenes would be saved to the phunlet directory
  + Fixed a bug where importing a phunlet would change the scene name
  + Restored the "clear scene" file menu button
* Thu Mar 20 2008 lars@linux-schulserver.de
- initial package 3.12
